import unittest

from automon.integrations.seleniumWrapper import SeleniumBrowser, ChromeWrapper

browser = SeleniumBrowser()
browser.config.webdriver_wrapper = ChromeWrapper()
browser.config.webdriver_wrapper.enable_defaults().enable_headless()


class SeleniumClientTest(unittest.TestCase):
    try:
        if browser.run():

            def test_fake_page(self):
                self.assertFalse(browser.get('http://555.555.555.555'))

            def test_real_page(self):
                if browser.get('http://1.1.1.1'):
                    self.assertTrue(True)

            def test_screenshot_png(self):
                if browser.get('http://google.com'):
                    self.assertTrue(browser.get_screenshot_as_png())

            def test_screenshot_base64(self):
                if browser.get('http://yahoo.com'):
                    self.assertTrue(browser.get_screenshot_as_base64())

            def test_screenshot_file(self):
                if browser.get('http://bing.com'):
                    self.assertTrue(browser.save_screenshot())
                    self.assertTrue(browser.save_screenshot(folder='./'))

            def test_by(self):
                self.assertTrue(browser.by)

            def test_config(self):
                self.assertTrue(browser.config)

            def test_logs(self):
                if browser.get('http://1.1.1.1'):
                    self.assertTrue(browser.logs)

            def test_webdriver(self):
                self.assertTrue(browser.webdriver)

            def test_get_logs(self):
                if browser.get('http://1.1.1.1'):
                    self.assertTrue(browser.get_logs())

            def test_get_log_browser(self):
                if browser.get('http://1.1.1.1'):
                    try:
                        self.assertTrue(browser.get_log_browser())
                    except:
                        pass

            def test_get_log_driver(self):
                if browser.get('http://1.1.1.1'):
                    try:
                        self.assertTrue(browser.get_log_driver())
                    except:
                        pass

            def test_get_log_performance(self):
                if browser.get('http://1.1.1.1'):
                    try:
                        self.assertTrue(browser.get_log_performance())
                    except:
                        pass

            def test_check_page_load_finished(self):
                if browser.get('http://1.1.1.1'):
                    self.assertTrue(browser.check_page_load_finished())

            def test_keys(self):
                self.assertTrue(browser.keys)

            def test_refresh(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.refresh())

            def test_url(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.url)

            def test_user_agent(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.user_agent)

            def test__current_url(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser._current_url)

            def test_current_url(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.current_url)

            def test_current_window_handle(self):
                self.assertTrue(browser.current_window_handle)

            def test_window_size(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.window_size)

            def test__screenshot_name(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser._screenshot_name)

            def test_action_click(self):
                NotImplemented

            def test_action_scroll_to_bottom(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.action_scroll_to_bottom())

            def test_action_scroll_down(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.action_scroll_down())

            def tset_action_scroll_up(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.action_scroll_up())

            def tset_action_type(self):
                NotImplemented

            def test_action_type_up(self):
                NotImplemented

            def test_action_type_down(self):
                NotImplemented

            def test_add_cookie(self):
                NotImplemented

            def test_add_cookie_from_file(self):
                NotImplemented

            def tset_add_cookies_from_list(self):
                NotImplemented

            def test_add_cookie_from_current_url(self):
                if browser.get('https://1.1.1.1'):
                    try:
                        self.assertTrue(browser.add_cookie_from_current_url())
                    except:
                        pass

            def test_add_cookie_from_url(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.save_cookies_for_current_url())
                    try:
                        self.assertTrue(browser.add_cookie_from_url('https://1.1.1.1'))
                    except:
                        pass

            def test_add_cookie_from_base64(self):
                NotImplemented

            def test_autosave_cookies(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.autosave_cookies())

            def test_delete_all_cookies(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.delete_all_cookies())

            def test__url_filename(self):
                self.assertTrue(browser._url_filename('https://1.1.1.1'))

            def test_get_cookie(self):
                NotImplemented

            def test_get_cookies(self):
                if browser.get('https://1.1.1.1'):
                    self.assertEqual(browser.get_cookies(), [])

            def test_get_cookies_base64(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_cookies_base64())

            def test_get_cookies_json(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_cookies_json())

            def test_get_cookies_summary(self):
                if browser.get('https://1.1.1.1'):
                    self.assertEqual(browser.get_cookies_summary(), {})

            def test_close(self):
                NotImplemented

            def test_error_parsing(self):
                NotImplemented

            def test_find_page_source_with_regex(self):
                NotImplemented

            def test_find_all_with_beautifulsoup(self):
                NotImplemented

            def test_find_anything(self):
                NotImplemented

            def test_find_anything_with_beautifulsoup(self):
                NotImplemented

            def test_find_element(self):
                NotImplemented

            def test_find_elements(self):
                NotImplemented

            def test_find_elements_with_beautifulsoup(self):
                NotImplemented

            def test_find_xpath(self):
                NotImplemented

            def test_get(self):
                self.assertTrue(browser.get('https://1.1.1.1'))

            def test_get_page(self):
                self.assertTrue(browser.get_page('https://1.1.1.1'))

            def test_get_page_source(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_page_source())

            def test_get_page_source_pandas(self):
                if browser.get('https://1.1.1.1'):
                    try:
                        self.assertTrue(browser.get_page_source_pandas())
                    except:
                        pass

            def test_get_page_source_beautifulsoup(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_page_source_beautifulsoup())

            def test_get_random_user_agent(self):
                self.assertTrue(browser.get_random_user_agent())

            def test_get_screenshot_as_base64(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_screenshot_as_base64())

            def test_get_screenshot_as_file(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_screenshot_as_file())

            def test_get_screenshot_as_png(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.get_screenshot_as_png())

            def test_is_running(self):
                self.assertTrue(browser.is_running())

            def test_load_cookies_for_current_url(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.load_cookies_for_current_url())

            def test_open_file(self):
                NotImplemented

            def test_page_source(self):
                self.assertTrue(browser.page_source)

            def test__urllib(self):
                self.assertTrue(browser._urllib)

            def test_urlparse(self):
                self.assertTrue(browser.urlparse('https://1.1.1.1'))

            def test_quit(self):
                NotImplemented

            def tset_run(self):
                self.assertTrue(browser.run())

            def tset_save_cookies_for_current_url(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.save_cookies_for_current_url())

            def test_save_cookies_to_file(self):
                NotImplemented

            def test_save_page_to_file(self):
                if browser.get('https://1.1.1.1'):
                    self.assertTrue(browser.save_page_to_file())

            def test_save_screenshot(self):
                self.assertTrue(browser.save_screenshot())

            def test_set_window_size(self):
                self.assertTrue(browser.set_window_size())

            def test_set_window_position(self):
                self.assertTrue(browser.set_window_position())

            def test_start(self):
                NotImplemented

            def test_switch_to_new_window_tab(self):
                self.assertTrue(browser.switch_to_new_window_tab())

            def test_switch_to_new_window_window(self):
                self.assertTrue(browser.switch_to_new_window_window())

            def test_wait_for_anything(self):
                NotImplemented

            def test_wait_for_anything_with_beautifulsoup(self):
                NotImplemented

            def test_wait_for_element(self):
                NotImplemented

            def test_wait_for_elements(self):
                NotImplemented

            def test_wait_for_id(self):
                NotImplemented

            def test_wait_for_xpath(self):
                NotImplemented

    except:
        pass


if __name__ == '__main__':
    unittest.main()
    browser.quit()



import unittest

from automon.integrations.requestsWrapper import RequestsClient
from automon.integrations.requestsWrapper import RequestsConfig

r = RequestsClient()
r.config.use_random_proxies = True

working_proxies = []


class Test(unittest.TestCase):
    def test_get(self):
        r.get('https://one.one.one.one/')

        if r.status_code:
            print(f'OK :: {r.proxies} :: {r.content} :: {r.status_code=}')
            working_proxies.append(r.proxies)
            pass


if __name__ == '__main__':
    unittest.main()



import automon
import re
import pandas
import random

import automon.integrations.requestsWrapper


def proxy_site_spys():
    # https://spys.me/proxy.txt
    proxies_table = automon.integrations.requestsWrapper.RequestsClient('https://spys.me/proxy.txt')
    proxies_table.get()

    MATCHED = []
    MISS_MATCHED = []

    for line in proxies_table.text.splitlines():
        # IP address:Port CountryCode-Anonymity(Noa/Anm/Hia)-SSL_support(S)-Google_passed(+)
        mapping_anonymity = dict(
            N='Noa',
            A='Anm',
            H='Hia'
        )
        mapping_ssl = dict(
            S=True
        )
        mapping_google = {
            "+": True,
            '-': False
        }

        search = re.compile(
            r'(\d+[.]\d+[.]\d+[.]\d+:\d+)\s'
            r'(\w{2})[-]?'
            r'([NAH!]{1,2})\s?[-]?'
            r'([S!]{1,2}|[-])?\s?'
            r'([-+])?\s?'
        ).fullmatch(line)

        if search:
            proxy_IpPort, proxy_CountryCode, proxy_Anonymity, proxy_SslSupport, proxy_GooglePassed = search.groups()

            mapping_search = dict(
                proxy_IpPort='IP Address and Port',
                proxy_CountryCode='Code',
                proxy_Anonymity='Anonymity',
                proxy_SslSupport='Https',
                proxy_GooglePassed='Google',
            )

            search_groups = dict(
                proxy_IpPort=proxy_IpPort,
                proxy_CountryCode=proxy_CountryCode,
                proxy_Anonymity=proxy_Anonymity,
                proxy_SslSupport=proxy_SslSupport,
                proxy_GooglePassed=proxy_GooglePassed,
            )

            search = dict(
                fullmatch=search,
                search_groups=search_groups,
                raw=line,
            )

            MATCHED.append(search)
        else:
            MISS_MATCHED.append(line)

    proxies_table = pandas.DataFrame(MATCHED)
    proxies_table = pandas.DataFrame(pandas.DataFrame(MATCHED)['search_groups'].tolist())

    proxies_table['IP Address'] = proxies_table['proxy_IpPort'].apply(
        lambda x: x.split(":")[0]
    )
    proxies_table['Port'] = proxies_table['proxy_IpPort'].apply(
        lambda x: x.split(":")[1]
    )
    proxies_table = proxies_table.drop(columns=['proxy_IpPort'])
    proxies_table['proxy_Anonymity'] = proxies_table['proxy_Anonymity'].apply(
        lambda x: (mapping_anonymity[x[0]], x[1:]) if x[1:] else mapping_anonymity[x[0]]
    )
    proxies_table['proxy_SslSupport'] = proxies_table[proxies_table['proxy_SslSupport'].notna()][
        'proxy_SslSupport'].apply(
        lambda x: (mapping_ssl[x[0]], x[1:])).apply(
        lambda x: x[0] if not x[1] else x
    )
    proxies_table['proxy_GooglePassed'] = proxies_table[proxies_table['proxy_GooglePassed'].notna()][
        'proxy_GooglePassed'].apply(
        lambda x: mapping_google[x]
    )
    proxies_table.rename(columns=mapping_search, inplace=True)

    return proxies_table


def proxy_site_free_proxy_list():
    # https://free-proxy-list.net/
    proxies_table = automon.integrations.requestsWrapper.RequestsClient('https://free-proxy-list.net/')
    proxies_table.get()

    proxies_table = pandas.read_html(proxies_table.text)[0]
    proxies_table['Https'] = proxies_table['Https'].apply(
        lambda x: True if x == 'yes' else x).apply(
        lambda x: False if x == 'no' else x
    )
    proxies_table['Google'] = proxies_table['Google'].apply(
        lambda x: True if x == 'yes' else x).apply(
        lambda x: False if x == 'no' else x
    )

    return proxies_table


def proxy_get_random_proxy() -> list:
    """Get proxies and return a list"""

    proxies_master_list = pandas.DataFrame()

    proxies_master_list = pandas.concat(
        [
            proxies_master_list,
            proxy_site_spys(),
            proxy_site_free_proxy_list(),
        ],
        ignore_index=True
    )

    return proxies_master_list


def proxy_filter_https_proxies():
    proxies_master_list = proxy_get_random_proxy()
    return proxies_master_list[proxies_master_list['Https'] == True]


def proxy_filter_https_ips_and_ports():
    proxies_master_list = proxy_filter_https_proxies()
    ips_and_ports = [f'{x}:{y}' for x, y in proxies_master_list[['IP Address', 'Port']].to_records(index=False)]

    return ips_and_ports


def proxy_filter_https_ips_and_ports_get_random():
    return random.choice(proxy_filter_https_ips_and_ports())



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="automonisaur",
    version="0.6.7",
    author="naisanza",
    author_email="naisanza@gmail.com",
    description="Core libraries for automonisaur",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/TheShellLand/automonisaur",
    packages=setuptools.find_packages(),
    tests_require=["pytest"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
    license_files="LICENSE",
    python_requires='>=3.10',
    install_requires=[]
)
